@@ -2,6 +2,6 @@ from .card import Card
 from .card_message import CardMessage
 from .color import Color
 from .element import Element
-from .interface import (ThemeTypes, TextTypes, SizeTypes, ClickTypes, SectionModeTypes, CountdownModeTypes, FileTypes)
+from .interface import Types
 from .module import Module
 from .struct import Struct
