@@ -4,7 +4,7 @@ from typing import Union, List, Dict
 
 from . import api
 from .gateway import Requestable, Gateway
-from .interface import LazyLoadable, MessageTypes, ChannelTypes
+from .interface import LazyLoadable, MessageTypes, ChannelTypes, SlowModeTypes
 from .role import Role
 from .user import User
 
@@ -128,6 +128,26 @@ class PublicChannel(Channel, ABC):
         self._update_fields(**(await self.gate.exec_req(api.Channel.view(self.id))))
         self._loaded = True
 
+    async def update(self, name: str = None, topic: str = None, slow_mode: Union[int, SlowModeTypes] = None) -> dict:
+        """
+        update channel's settings
+        """
+        params = {'channel_id': self.id}
+        if name is not None:
+            params['name'] = name
+        if topic is not None:
+            params['topic'] = topic
+        if slow_mode is not None:
+            if isinstance(slow_mode, int):
+                if slow_mode not in SlowModeTypes.possible_value():
+                    raise ValueError('Unsupported value: ' + str(slow_mode))
+                params['slow_mode'] = slow_mode
+            elif isinstance(slow_mode, SlowModeTypes):
+                params['slow_mode'] = slow_mode.value
+        rt = await self.gate.exec_req(api.Channel.update(**params))
+        await self.load()
+        return rt
+
     async def fetch_permission(self, force_update: bool = True) -> ChannelPermission:
         if force_update or not self.permission.loaded:
             await self.permission.load()
