@@ -20,3 +20,9 @@ class Role:
         self.hoist: int = kwargs.get("hoist", 0)
         self.mentionable: int = kwargs.get("mentionable", 0)
         self.permissions: int = kwargs.get("permissions", 0)
+
+    def has_permission(self, bit_value: int) -> bool:
+        """
+        bitValue see https://developer.kaiheila.cn/doc/http/guild-role#%E6%9D%83%E9%99%90%E8%AF%B4%E6%98%8E
+        """
+        return self.permissions & (1 << bit_value) != 0
